==> huaweicloudsdkdgc-3.1.76-py2.py3-none-any.whl: huaweicloudsdkdgc/v1/model/depend_package.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DependPackage:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'type': 'str',
        'location': 'str'
    }

    attribute_map = {
        'type': 'type',
        'location': 'location'
    }

    def __init__(self, type=None, location=None):
        """DependPackage

        The model defined in huaweicloud sdk

        :param type: 文件类型
        :type type: str
        :param location: 文件路径
        :type location: str
        """
        
        

        self._type = None
        self._location = None
        self.discriminator = None

        if type is not None:
            self.type = type
        if location is not None:
            self.location = location

    @property
    def type(self):
        """Gets the type of this DependPackage.

        文件类型

        :return: The type of this DependPackage.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this DependPackage.

        文件类型

        :param type: The type of this DependPackage.
        :type type: str
        """
        self._type = type

    @property
    def location(self):
        """Gets the location of this DependPackage.

        文件路径

        :return: The location of this DependPackage.
        :rtype: str
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this DependPackage.

        文件路径

        :param location: The location of this DependPackage.
        :type location: str
        """
        self._location = location

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DependPackage):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdgc-3.1.145-py2.py3-none-any.whl: huaweicloudsdkdgc/v1/model/depend_package.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DependPackage:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'type': 'str',
        'location': 'str'
    }

    attribute_map = {
        'type': 'type',
        'location': 'location'
    }

    def __init__(self, type=None, location=None):
        r"""DependPackage

        The model defined in huaweicloud sdk

        :param type: 文件类型
        :type type: str
        :param location: 文件路径
        :type location: str
        """
        
        

        self._type = None
        self._location = None
        self.discriminator = None

        if type is not None:
            self.type = type
        if location is not None:
            self.location = location

    @property
    def type(self):
        r"""Gets the type of this DependPackage.

        文件类型

        :return: The type of this DependPackage.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        r"""Sets the type of this DependPackage.

        文件类型

        :param type: The type of this DependPackage.
        :type type: str
        """
        self._type = type

    @property
    def location(self):
        r"""Gets the location of this DependPackage.

        文件路径

        :return: The location of this DependPackage.
        :rtype: str
        """
        return self._location

    @location.setter
    def location(self, location):
        r"""Sets the location of this DependPackage.

        文件路径

        :param location: The location of this DependPackage.
        :type location: str
        """
        self._location = location

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DependPackage):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
